@@ -17,7 +17,7 @@ package Image::ExifTool::Validate;
 use strict;
 use vars qw($VERSION %exifSpec);
 
-$VERSION = '1.09';
+$VERSION = '1.10';
 
 use Image::ExifTool qw(:Utils);
 use Image::ExifTool::Exif;
@@ -255,7 +255,8 @@ my %validateInfo = (
         generated only if specifically requested.  Requesting this tag automatically
         enables the L<API Validate option|../ExifTool.html#Validate>, imposing
         additional validation checks when extracting metadata.  Returns the number
-        of errors, warnings and minor warnings encountered
+        of errors, warnings and minor warnings encountered.  Note that the Validate
+        feature focuses mainly on validation of TIFF/EXIF metadata and files
     },
     PrintConv => {
         '0 0 0' => 'OK',
@@ -427,6 +428,7 @@ sub ValidateExif($$$$$$$$)
 #         2) directory name, 3) optional flag for minor warning
 sub ValidateOffsetInfo($$$;$)
 {
+    local $_;
     my ($et, $offsetInfo, $dirName, $minor) = @_;
 
     my $fileSize = $$et{VALUE}{FileSize} or return;
@@ -438,10 +440,14 @@ sub ValidateOffsetInfo($$$;$)
     # (don't test 3FR, RWL or RW2 files)
     return if $$et{TIFF_TYPE} =~ /^(3FR|RWL|RW2)$/;
 
+    Image::ExifTool::Exif::ValidateImageData($et, $offsetInfo, $dirName);
+
+    # loop through all offsets
     while (%$offsetInfo) {
         my ($id1) = sort keys %$offsetInfo;
         my $offsets = $$offsetInfo{$id1};
         delete $$offsetInfo{$id1};
+        next unless ref $offsets eq 'ARRAY';
         my $id2 = $$offsets[0]{OffsetPair};
         unless (defined $id2 and $$offsetInfo{$id2}) {
             unless ($$offsets[0]{NotRealPair} or (defined $id2 and $id2 == -1)) {
