@@ -88,6 +88,40 @@ sub ValidateXMP($;$)
     return 1;
 }
 
+#------------------------------------------------------------------------------
+# Validate XMP property
+# Inputs: 0) ExifTool ref, 1) validate hash ref
+# - issues warnings if problems detected
+sub ValidateProperty($$)
+{
+    my ($et, $propList) = @_;
+
+    if ($$et{XmpValidate} and @$propList > 2) {
+        if ($$propList[0] =~ /^x:x[ma]pmeta$/ and
+            $$propList[1] eq 'rdf:RDF' and
+            $$propList[2] =~ /rdf:Description( |$)/)
+        {
+            if (@$propList > 3) {
+                if ($$propList[-1] =~ /^rdf:(Bag|Seq|Alt)$/) {
+                    $et->Warn("Ignored empty $$propList[-1] list for $$propList[-2]", 1);
+                } else {
+                    my $xmpValidate = $$et{XmpValidate};
+                    my $path = join('/', @$propList[3..$#$propList]);
+                    if (defined $$xmpValidate{$path}) {
+                        $et->Warn("Duplicate XMP property: $path") if defined $$xmpValidate{$path};
+                    } else {
+                        $$xmpValidate{$path} = 1;
+                    }
+                }
+            }
+        } elsif ($$propList[0] ne 'rdf:RDF' or
+                 $$propList[1] !~ /rdf:Description( |$)/)
+        {
+            $et->Warn('Improperly enclosed XMP property: ' . join('/',@$propList));
+        }
+    }
+}
+
 #------------------------------------------------------------------------------
 # Check XMP date values for validity and format accordingly
 # Inputs: 1) date string
@@ -267,6 +301,7 @@ sub SetPropertyPath($$;$$$$)
             SetPropertyPath($tagTablePtr, $$tagInfo{RootTagInfo}{TagID});
             return if $$tagInfo{PropertyPath};
             warn "Internal Error: Didn't set path from root for $tagID\n";
+            warn "(Is the Struct NAMESPACE defined?)\n";
         }
     }
     my $ns = $$tagInfo{Namespace} || $$table{NAMESPACE};
